
#include <QFile>

#include <malloc.h>
#include "systemwatcher.h"

SystemWatcher::SystemWatcher()
:   mIterations(0)
{
    connect(&t,SIGNAL(timeout()),this,SLOT(updateMemInfo()));
    t.start(1000);
}

void SystemWatcher::updateMemInfo()
{
    qDebug("--------------- Iterations: %d  -------------------------------", mIterations ++);

    switchSource();
    memInfoFromFile();
    heapAllocs();
}

void SystemWatcher::switchSource()
{
    if (mLoaderSource == "" )
        mLoaderSource = "qmlui/rectangle2/qml/Rectangle2.qml";
    else
        mLoaderSource = "";

    emit loaderSourceChanged();
}

void SystemWatcher::memInfoFromFile()
{
    static QFile meminfo("/proc/meminfo");

    if (!meminfo.isOpen())
    {
        if (!meminfo.open(QIODevice::ReadOnly | QIODevice::Text))
        {
            return;
        }
    }

    meminfo.seek(0);

    do
    {
        mSystemFreeMem = meminfo.readLine();

    } while (!mSystemFreeMem.contains("MemFree:"));

    mSystemFreeMem = mSystemFreeMem.remove("MemFree:");
    mSystemFreeMem = mSystemFreeMem.remove("kB");
    mSystemFreeMem = mSystemFreeMem.remove(" ");
    mSystemFreeMem = mSystemFreeMem.remove("\t");
    mSystemFreeMem = mSystemFreeMem.remove("\n");

    qDebug("System Free Memory: %d", mSystemFreeMem.toInt());

    emit systemFreeMemChanged();

}

void SystemWatcher::heapAllocs()
{
    int uordblks = mallinfo().uordblks;
    mTotalAllocs = QString::number(uordblks);

    emit totalAllocsChanged();

    qDebug("Total Allocs: %d", mTotalAllocs.toInt());

}


