#ifndef SYSTEMWATCHER_H
#define SYSTEMWATCHER_H

#include <QObject>
#include <QTimer>

class SystemWatcher : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString loaderSource READ loaderSource NOTIFY loaderSourceChanged)
    QString loaderSource() {return mLoaderSource;}

    //Memory usage information
    Q_PROPERTY(QString systemFreeMem READ systemFreeMem NOTIFY systemFreeMemChanged)
    QString systemFreeMem() const {return mSystemFreeMem;}

    Q_PROPERTY(QString totalAllocs READ totalAllocs NOTIFY totalAllocsChanged)
    QString totalAllocs() const {return mTotalAllocs;}


public:
    explicit    SystemWatcher();

    int         mIterations;

    QString     mLoaderSource;

    QTimer      t;

    QString      mSystemFreeMem;
    QString      mTotalAllocs;

signals:

    void        systemFreeMemChanged();
    void        totalAllocsChanged();

    void        loaderSourceChanged();

public slots:

    void    heapAllocs();
    void    updateMemInfo();

private:

    void    switchSource();
    void    memInfoFromFile();

};

#endif // SYSTEMWATCHER_H
